Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1245)

Unified Diff: chrome/browser/android/contextualsearch/contextual_search_ranker_logger_impl.h

Issue 2893943004: Refactor UKM interface for mojo-ification (Closed)
Patch Set: Fixed contextualsearch Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/android/contextualsearch/contextual_search_ranker_logger_impl.h
diff --git a/chrome/browser/android/contextualsearch/contextual_search_ranker_logger_impl.h b/chrome/browser/android/contextualsearch/contextual_search_ranker_logger_impl.h
index 6e3ff38e8307aa98e3a5a671ced4a5cd90a2aa2f..52490590a84a48bbf392198ed2288694806ba1e0 100644
--- a/chrome/browser/android/contextualsearch/contextual_search_ranker_logger_impl.h
+++ b/chrome/browser/android/contextualsearch/contextual_search_ranker_logger_impl.h
@@ -6,13 +6,13 @@
#define CHROME_BROWSER_ANDROID_CONTEXTUALSEARCH_CONTEXTUAL_SEARCH_RANKER_LOGGER_IMPL_H_
#include "base/android/jni_android.h"
-#include "components/ukm/ukm_service.h"
+#include "components/ukm/public/ukm_recorder.h"
#include "url/gurl.h"
class GURL;
namespace ukm {
-class UkmService;
+class UkmRecorder;
} // namespace ukm
class ContextualSearchRankerLoggerImpl {
@@ -44,12 +44,12 @@ class ContextualSearchRankerLoggerImpl {
void WriteLogAndReset(JNIEnv* env, jobject obj);
private:
- // Set the UKM service and base-page URL.
- // TODO(donnd): write a test, using this to inject a test-ukm-service.
- void SetUkmService(ukm::UkmService* ukm_service, const GURL& page_url);
+ // Set the UKM recorder and base-page URL.
+ // TODO(donnd): write a test, using this to inject a test-ukm-recorder.
+ void SetUkmRecorder(ukm::UkmRecorder* ukm_recorder, const GURL& page_url);
// Used to log URL-keyed metrics. This pointer will outlive |this|.
- ukm::UkmService* ukm_service_;
+ ukm::UkmRecorder* ukm_recorder_;
// The UKM source ID being used for this session.
int32_t source_id_;

Powered by Google App Engine
This is Rietveld 408576698